==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/showGeneSet.R <==
## show method -- default display
#showGeneSet <- function (object, full=FALSE, ...) {
showGeneSet <- function (object) {
                full<-FALSE
		if (length(object@transTables) == 0)
			stop("Code Translation Tables not found.")

                if (nmarker(object)>20 && !full)
                  {
                    someMarkers <- TRUE
                    markers <- c(1:6,nrow(object@callCodes)-(6:0))
                    warning("geneSet Object has ",nrow(object@callCodes),
                            " markers.  Only first and last 6 displayed")
                  }
                else
                  {
                    markers <- 1:nmarker(object)
                    someMarkers <- FALSE
                  }

                
                if (nobs(object)>20 && !full)
                  {
                    someObs <- TRUE
                    obs <- c(1:6,ncol(object@callCodes)-(6:0))
                    warning("geneSet Object has ",ncol(object@callCodes),
                            " observations.  Only first and last 6 displayed")
                  }
                else
                  {
                    obs <- 1:nobs(object)
                    someObs <- FALSE
                  }


                ## Problem is that if nobs(object) == 0, obs <- c(1,0),
                ## which in turn creates problems for the following statement.


                ## An alternative could be - to use
                if(someObs || someMarkers )
                  data <- object[markers,obs]
                else
                  data <- object

                tmp <- t(genotypes((data)))
                
                ##tmp <- decodeCallCodes(object@callCodes[markers,obs],
                ##                       object@transTables,
                ##                       object@markerInfo[markers,])


                
                if( someObs )
                    tmp <- cbind(tmp[,1:6],
                                 rep("...",length=nrow(tmp)),
                                 tmp[,7:12])

                if( someMarkers )
                  tmp <- rbind(tmp[1:6,],
                               rep(" . ",length=ncol(tmp)),
                               rep(" . ",length=ncol(tmp)),
                               rep(" . ",length=ncol(tmp)),
                               tmp[7:12,])

                cat("\n")
                cat("geneSet object\n")
                cat("------------------\n")
                cat("\n")
                cat("Number of Markers:     ", nrow(object@callCodes),"\n")
                cat("Number of Observations:", ncol(object@callCodes),"\n")
                cat("\n")
                if(!is.null(sampleInfo(object)))
                   {
                     cat(strwrap(
                                 paste("Sample variables:",
                                       paste(colnames(
                                                      sampleInfo(object)
                                                      ),
                                             collapse=", ")
                                       ),
                                 indent=0,
                                 exdent=18),
                         collapse="\n")
                   }
                cat("\n")
                cat("Genetic data:\n")
                cat("\n")
                print(tmp, quote=FALSE)
                invisible(tmp)
              }


setMethod("show", "geneSet", showGeneSet)


## show beginning 
#setMethod("head", "geneSet",
#          function (x, n=6, ...) {
#            n <- min(n, nrow(x@markerInfo))
#            if (length(x@transTables) == 0)
#              stop("Code Translation Tables not found.")
#            tmp <- t(genotypes(x,
##                             marker=seq(1,n)
#                             ))
#            print(tmp, quote=FALSE, ...)
#            invisible(tmp)
#          }
#          )

## show end
#setMethod("tail", "geneSet",
#          function (x, n=6, ...) {
#            n <- min(n, nrow(x@markerInfo))
#            if (length(x@transTables) == 0)
#              stop("Code Translation Tables not found.")
#            lastn <- nrow(x@callCodes)-(n:1)+1
#            tmp <- t(genotypes(x, marker=lastn ))
#            print(tmp, quote=FALSE, ...)
#            invisible(tmp)
#          }
##          )

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/showGeneSet.R <==
## show method -- default display
#showGeneSet <- function (object, full=FALSE, ...) {
showGeneSet <- function (object) {
                full<-FALSE
		if (length(object@transTables) == 0)
			stop("Code Translation Tables not found.")

                if (nmarker(object)>20 && !full)
                  {
                    someMarkers <- TRUE
                    markers <- c(1:6,nrow(object@callCodes)-(6:0))
                    warning("geneSet Object has ",nrow(object@callCodes),
                            " markers.  Only first and last 6 displayed")
                  }
                else
                  {
                    markers <- 1:nmarker(object)
                    someMarkers <- FALSE
                  }

                
                if (nobs(object)>20 && !full)
                  {
                    someObs <- TRUE
                    obs <- c(1:6,ncol(object@callCodes)-(6:0))
                    warning("geneSet Object has ",ncol(object@callCodes),
                            " observations.  Only first and last 6 displayed")
                  }
                else
                  {
                    obs <- 1:nobs(object)
                    someObs <- FALSE
                  }


                ## Problem is that if nobs(object) == 0, obs <- c(1,0),
                ## which in turn creates problems for the following statement.


                ## An alternative could be - to use
                if(someObs || someMarkers )
                  data <- object[markers,obs]
                else
                  data <- object

                tmp <- t(genotypes((data)))
                
                ##tmp <- decodeCallCodes(object@callCodes[markers,obs],
                ##                       object@transTables,
                ##                       object@markerInfo[markers,])


                
                if( someObs )
                    tmp <- cbind(tmp[,1:6,drop=FALSE],
                                 rep("...",length=nrow(tmp)),
                                 tmp[,7:12,drop=FALSE])

                if( someMarkers )
                  tmp <- rbind(tmp[1:6,,drop=FALSE],
                               rep(" . ",length=ncol(tmp)),
                               rep(" . ",length=ncol(tmp)),
                               rep(" . ",length=ncol(tmp)),
                               tmp[7:12,,drop=FALSE])

                cat("\n")
                cat("geneSet object\n")
                cat("------------------\n")
                cat("\n")
                cat("Number of Markers:     ", nrow(object@callCodes),"\n")
                cat("Number of Observations:", ncol(object@callCodes),"\n")
                cat("\n")
                if(!is.null(sampleInfo(object)))
                   {
                     cat(strwrap(
                                 paste("Sample variables:",
                                       paste(colnames(
                                                      sampleInfo(object)
                                                      ),
                                             collapse=", ")
                                       ),
                                 indent=0,
                                 exdent=18),
                         collapse="\n")
                   }
                cat("\n")
                cat("Genetic data:\n")
                cat("\n")
                print(tmp, quote=FALSE)
                invisible(tmp)
              }


setMethod("show", "geneSet", showGeneSet)


## show beginning 
#setMethod("head", "geneSet",
#          function (x, n=6, ...) {
#            n <- min(n, nrow(x@markerInfo))
#            if (length(x@transTables) == 0)
#              stop("Code Translation Tables not found.")
#            tmp <- t(genotypes(x,
##                             marker=seq(1,n)
#                             ))
#            print(tmp, quote=FALSE, ...)
#            invisible(tmp)
#          }
#          )

## show end
#setMethod("tail", "geneSet",
#          function (x, n=6, ...) {
#            n <- min(n, nrow(x@markerInfo))
#            if (length(x@transTables) == 0)
#              stop("Code Translation Tables not found.")
#            lastn <- nrow(x@callCodes)-(n:1)+1
#            tmp <- t(genotypes(x, marker=lastn ))
#            print(tmp, quote=FALSE, ...)
#            invisible(tmp)
#          }
##          )
